@@ -12,7 +12,7 @@ case "$1" in
            remap_page_range(NULL, 0L, 0L, 0L, pgprot);
         }" > conftest.c
 
-        RPR_TEST_5=$(gcc -c conftest.c -o /dev/null $* -D__KERNEL__ 2>&1)
+        gcc -c conftest.c -o conftest.5.o $* -D__KERNEL__ > /dev/null 2>&1
 
         echo "#include <linux/mm.h>
         int do_test_remap_page_range(void) {
@@ -20,18 +20,22 @@ case "$1" in
            remap_page_range(0L, 0L, 0L, pgprot);
         }" > conftest.c
 
-        RPR_TEST_4=$(gcc -c conftest.c -o /dev/null $* -D__KERNEL__ 2>&1)
+        gcc -c conftest.c -o conftest.4.o $* -D__KERNEL__ > /dev/null 2>&1
 
-        if   test -z "$RPR_TEST_4"; then
+        if   test -f conftest.4.o; then
           echo "4"
-        elif test -z "$RPR_TEST_5"; then
+          rm -f conftest.{c,4.o}
+        elif test -f conftest.5.o; then
           echo "5"
+          rm -f conftest.{c,5.o}
         else
-          echo "                                                           "
-          echo "Warning! conftest.sh was unable to determine the number of "
-          echo "arguments expected by remap_page_range: assuming 4.        "
-          echo "                                                           "
-          echo "4"
+          #
+          # We couldn't determine the number of arguments expected by the
+          # remap_page_range function.
+          #
+          rm -f conftest.{c,*.o}
+          exit 1
         fi
     ;;
 esac
+
