@@ -618,6 +618,7 @@ static void nvos_proc_create(void)
 #endif
 }
 
+#ifdef CONFIG_PROC_FS
 static void nvos_proc_remove_all(struct proc_dir_entry *entry)
 {
     while (entry) {
@@ -628,6 +629,7 @@ static void nvos_proc_remove_all(struct proc_dir_entry *entry)
         entry = next;
     }
 }
+#endif
 
 static void nvos_proc_remove(void)
 {
@@ -2291,7 +2293,6 @@ nv_alloc_pages(
         // in this case, 'physical address' is within the agp aperture
         *pAddress = (void *) (nv->agp.address + (offset << PAGE_SHIFT));
         at->agp_offset = offset;
-        nv->agp_buffers++;
     }
     else 
     {
@@ -2405,6 +2406,9 @@ nv_free_pages(
 
     if (agp_memory)
     {
+        if (NV_AGP_DISABLED(nv))
+            return -1;
+
         /* only lock ldata while removing 'at' from the list */
         nv_lock_at(nv);
         at = nvl_find_alloc(nvl, (unsigned long) *pAddress, NV_ALLOC_TYPE_AGP);
@@ -2428,14 +2432,6 @@ nv_free_pages(
                 nvos_unlock_and_free_pages(at->usage_count, at->page_table, at->num_pages);
             }
         }
-
-        /* we may hold off on disabling agp until all buffers are freed */
-        if (rmStatus == RM_OK)
-        {
-            nv->agp_buffers--;
-            if (!nv->agp_buffers && nv->agp_teardown)
-                nv_agp_teardown(nv);
-        }
     } else {
         /* only lock ldata while removing 'at' from the list */
         nv_lock_at(nv);
@@ -2603,9 +2599,10 @@ nv_agp_init(
 {
     U032 status = 1;
 
-    nv_printf(NV_DBG_SETUP, "NVRM: nv_agp_init\n");
+    if (NV_AGP_ENABLED(nv))
+        return -1;
 
-    nv_lock_ldata(nv);
+    nv_printf(NV_DBG_SETUP, "NVRM: nv_agp_init\n");
 
     if (config & NVOS_AGP_CONFIG_OSAGP)
     {
@@ -2626,10 +2623,7 @@ nv_agp_init(
          * the machine.
          */
         if (status < 0)
-        {
-            nv_unlock_ldata(nv);
-            return 1;
-        }
+            return status;
     }
 
     /* we're either explicitly not using agpgart,
@@ -2652,8 +2646,6 @@ nv_agp_init(
                 nv->agp_config = NVOS_AGP_CONFIG_NVAGP;
     }
 
-    nv_unlock_ldata(nv);
-
     nv_printf(NV_DBG_SETUP, 
         "NVRM: agp_init finished with status 0x%x and config %d\n",
         status, nv->agp_config);
@@ -2674,25 +2666,13 @@ nv_agp_teardown(
     if (NV_AGP_DISABLED(nv))
         return -1;
 
-    nv_lock_ldata(nv);
-
-    /* if agp buffers are still in use, don't teardown just yet */
-    if (nv->agp_buffers)
-    {
-        nv->agp_teardown = 1;
-        nv_unlock_ldata(nv);
-        return 0;
-    }
-
     if (NV_OSAGP_ENABLED(nv))
     {
         status = KernTeardownAGP(nv);
     } else
-        status = rm_shutdown_agp(nv);
+        status = rm_teardown_agp(nv);
 
-    nv->agp_teardown = 0;
     nv->agp_config = NVOS_AGP_CONFIG_DISABLE_AGP;
-    nv_unlock_ldata(nv);
 
     nv_printf(NV_DBG_SETUP, "NVRM: teardown finished with status 0x%x\n", 
         status);
