@@ -510,47 +510,6 @@ RM_STATUS os_kill_process(
 /*                                                                             */
 /*******************************************************************************/
 
-#undef DEBUG
-#define DEBUG 1         // for rest of this file, DEBUG is always on
-
-/*
- *  print or log error and freakout messages 
- *
- * These routines provide general purpose error reporting.
- * nv_error reports an error to stderr and allows use of
- * printf style formatting.  A newline is appended to all messages.
- * 
- * error_flag can be specified as any of the following:
- *
- *      NV_ERROR_ERRNO       -- include errno text in output
- *      NV_ERROR_STATUS      -- RM status is in error_flag
- *      NV_ERROR_PANIC       -- halts local system after output
- *      NV_ERROR_MESSAGE     -- just do the printing; no hint of error
- *
- *
- * It can also include an errno value which can be OR'd
- * with the above flags.  In this case, the errno within error_flag
- * is used instead of the global errno.
- * 
- * 
- * EXAMPLE
- *  #include <nv.h>
- *  nv_error(0, "stray interrupt %d", intr);
- *
- * EXAMPLE
- *        if ((fd = open(pathname, O_RDNLY)) < 0)
- *        {
- *            nv_error(NV_ERROR_ERRNO, "open of '%s' failed", pathname);
- *            goto failed;
- *        }
- *
- */
-
-//---------------------------------------------------------------------------
-//
-//  Debugging support.
-//
-//---------------------------------------------------------------------------
 
 // The current debug display level (default to maximum debug level)
 int cur_debuglevel = 0xaaaaaaaa;
@@ -1005,6 +964,7 @@ VOID os_dbg_set_level(U032 new_debuglevel)
  */
 VOID os_dbg_breakpoint(void)
 {
+#ifdef DEBUG
     out_string("Break\n");
 
 #if defined(CONFIG_X86_REMOTE_DEBUG)
@@ -1014,6 +974,8 @@ VOID os_dbg_breakpoint(void)
 #else
     out_string("Skipping INT 3, we don't like kernel panics\n");
 #endif
+
+#endif /* DEBUG */
 }
 
 
